package org.jtheque.films.controllers.impl.state.actor;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.films.controllers.able.IActorController;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.view.impl.fb.ActorFormBean;
import org.jtheque.films.view.impl.models.ActorsModel;
import org.jtheque.primary.controller.able.ControllerState;
import org.jtheque.primary.controller.able.FormBean;
import org.jtheque.primary.od.abstraction.Data;
import org.jtheque.primary.view.able.ViewMode;

import javax.annotation.Resource;

/**
 * A actor controller state for the state "modify".
 *
 * @author Baptiste Wicht
 */
public final class ModifyActorState implements ControllerState {
    @Resource
    private IActorController controller;

    @Resource
    private IActorService actorService;

    @Override
    public ActorsModel getViewModel() {
        return controller.getViewModel();
    }

    @Override
    public void apply() {
        controller.getView().setEnabled(true);
        controller.getView().getToolbarView().setDisplayMode(ViewMode.EDIT);

        getViewModel().getCurrentActor().saveToMemento();
    }

    @Override
    public ControllerState save(FormBean bean) {
        ActorFormBean infos = (ActorFormBean) bean;

        String oldName = getViewModel().getCurrentActor().getAffichableText();

        actorService.edit(getViewModel().getCurrentActor(), infos);

        if (!oldName.equals(getViewModel().getCurrentActor().getAffichableText())) {
            controller.getView().resort();
            controller.getView().select(getViewModel().getCurrentActor());
        }

        return controller.getViewState();
    }

    @Override
    public ControllerState cancel() {
        getViewModel().getCurrentActor().restoreMemento();

        return controller.getViewState();
    }

    @Override
    public ControllerState create() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState manualEdit() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState delete() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState autoEdit(Data data) {
        ActorImpl actor = (ActorImpl) data;

        if (Managers.getManager(IViewManager.class).askI18nUserForConfirmation(
                "actor.dialogs.confirmSave", "actor.dialogs.confirmSave.title")) {
            controller.save();
        } else {
            getViewModel().getCurrentActor().restoreMemento();
        }

        getViewModel().setCurrentActor(actor);

        return controller.getAutoAddState();
    }

    @Override
    public ControllerState view(Data data) {
        ActorImpl actor = (ActorImpl) data;

        if (Managers.getManager(IViewManager.class).askUserForConfirmation(
                "actor.dialogs.confirmSave", "actor.dialogs.confirmSave.title")) {
            controller.save();
        } else {
            getViewModel().getCurrentActor().restoreMemento();
        }

        getViewModel().setCurrentActor(actor);

        return controller.getViewState();
    }
}