package org.jtheque.films.persistence.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.JThequeDao;
import org.jtheque.films.persistence.od.ActorImpl;

import java.util.List;

/**
 * A DAO for actors specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoActors extends JThequeDao {
    String TABLE = "T_FILM_ACTORS";

    /**
     * Cette mthode retourne l'ensemble des acteurs du programme.
     *
     * @return La liste des acteurs
     */
    List<ActorImpl> getActors();

    /**
     * Cette mthode permet de rcuprer un acteur  partir de son texte affichable.
     *
     * @param firstName The first name of the actor.
     * @param name      The name of the actor.
     * @return L'acteurs qui correspond  ce texte
     */
    ActorImpl getActor(String firstName, String name);

    /**
     * Cette mthode indique si un acteur existe ou non.
     *
     * @param firstName The first name of the actor.
     * @param name      The name of the actor.
     * @return true s'il existe, sinon false
     */
    boolean exists(String firstName, String name);

    /**
     * Indicate if the actor exist in the Dao.
     *
     * @param actor The actor we must test if it's exist.
     * @return <code>true</code> if the actor exist else <code>false</code>.
     */
    boolean exist(ActorImpl actor);

    /**
     * Save the actor on the database.
     *
     * @param actor The actor to save.
     */
    void save(ActorImpl actor);

    /**
     * Cette mthode permet de crer un nouvel acteur.
     *
     * @param actor L'acteur  crer
     */
    void create(ActorImpl actor);

    /**
     * Cette mthode permet de supprimmer un acteur.
     *
     * @param actor L'acteur  supprimmer
     * @return true if the object is deleted else false.
     */
    boolean delete(ActorImpl actor);

    ActorImpl getActor(int id);
}