package org.jtheque.films.persistence.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.JThequeDao;
import org.jtheque.films.persistence.od.FilmImpl;

import java.util.List;

/**
 * A DAO for films specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoFilms extends JThequeDao {
    String TABLE = "T_FILMS";
    String ACTORS_FILMS_TABLE = "T_ACTORS_FILMS";
    String KINDS_FILMS_TABLE = "T_KINDS_FILMS";

    /**
     * Return all the films of the current collection.
     *
     * @return All the films of the current collection.
     */
    List<FilmImpl> getFilms();

    /**
     * Return all the films.
     *
     * @return All the films.
     */
    List<FilmImpl> getAllFilms();

    /**
     * Cette mthode permet de rcuprer un film dans la base de donnes en fonction de son id.
     *
     * @param id L'id du film
     * @return Le film correspondant  l'id
     */
    FilmImpl getFilm(int id);

    /**
     * Cette mthode permet de crer un nouveau film.
     *
     * @param film Le film  crer
     */
    void create(FilmImpl film);

    /**
     * Create all the films in the list.
     *
     * @param films The films to create.
     */
    void createAll(List<FilmImpl> films);

    /**
     * Save the film on the database.
     *
     * @param film The film to save.
     */
    void save(FilmImpl film);

    /**
     * Cette mthode permet de supprimmer un film.
     *
     * @param film Le film  supprimmer
     * @return true if the object is deleted else false.
     */
    boolean delete(FilmImpl film);

    /**
     * Save all the films.
     */
    void saveAll();
}