package org.jtheque.films.persistence.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.JThequeDao;
import org.jtheque.films.persistence.od.RealizerImpl;

import java.util.List;

/**
 * A DAO for realizers specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoRealizers extends JThequeDao {
    String TABLE = "T_FILM_REALIZERS";

    /**
     * Cette mthode retourne l'ensemble des ralisateurs du programme.
     *
     * @return La liste des ralisateurs
     */
    List<RealizerImpl> getRealizers();

    /**
     * Indicate if the realizer exist in the Dao.
     *
     * @param realizer The realizer we must test if it's exist.
     * @return <code>true</code> if the realizer exist else <code>false</code>.
     */
    boolean exist(RealizerImpl realizer);

    /**
     * Cette mthode permet de rcuprer un ralisateur  partir de son ID. Si les ralisateurs ne sont pas encore
     * monts en RAM, on le fait.
     *
     * @param id L'id du ralisateur  rcuprer
     * @return Le ralisateur qui correspond  cet ID
     */
    RealizerImpl getRealizer(int id);

    /**
     * Cette mthode permet de rcuprer un ralisateur  partir de son texte affichable.
     *
     * @param firstName The first name of the actor.
     * @param name      The name of the actor.
     * @return The realizer corresponding to this name.
     */
    RealizerImpl getRealizer(String firstName, String name);

    /**
     * Cette mthode indique si un ralisateur existe ou non.
     *
     * @param firstName The first name of the actor.
     * @param name      The name of the actor.
     * @return true s'il existe, sinon false
     */
    boolean exists(String firstName, String name);

    /**
     * Cette mthode permet de supprimmer un ralisateur.
     *
     * @param realisateur Le ralisateur  supprimmer
     * @return true if the object is deleted else false.
     */
    boolean delete(RealizerImpl realisateur);

    /**
     * Save the realizer.
     *
     * @param realisateur The realizer to save.
     */
    void save(RealizerImpl realisateur);

    /**
     * Cette mthode permet de crer un nouveau ralisateur.
     *
     * @param realisateur Le ralisateur  crer
     */
    void create(RealizerImpl realisateur);
}