package org.jtheque.films.persistence.od.abstraction;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.utils.db.Note;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.primary.od.CollectionImpl;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.primary.od.*;
import org.jtheque.primary.od.abstraction.Data;
import org.jtheque.primary.od.abstraction.Notable;

import java.util.HashSet;
import java.util.Set;

/**
 * Represents the abstraction of a film.
 *
 * @author Baptiste Wicht
 */
public abstract class Film extends Data implements Notable {
    /* Paramtres du film */
    private CollectionImpl collection;
    private String title;
    private TypeImpl type;
    private RealizerImpl realizer;
    private LanguageImpl language;
    private int year;
    private int duration;
    private Note note;
    private LendingImpl lending;
    private String resume;
    private String comment;
    private String image;
    private String filePath;
    private Set<ActorImpl> actors = new HashSet<ActorImpl>(12);
    private Set<KindImpl> kinds = new HashSet<KindImpl>(5);
    private SagaImpl theSaga;

    /**
     * Cette mthode modifie le titre du film.
     *
     * @param title le nouveau titre
     */
    public final void setTitle(String title) {
        this.title = title;
    }

    /**
     * Cette mthode retourne le titre du film.
     *
     * @return Le titre du film
     */
    public final String getTitle() {
        return title;
    }

    /**
     * The collection of this film.
     *
     * @param collection The collection.
     */
    public final void setTheCollection(CollectionImpl collection) {
        this.collection = collection;
    }

    /**
     * Cette mthode retourne le genre du film.
     *
     * @return Le genre du film
     */
    public final CollectionImpl getTheCollection() {
        return collection;
    }

    /**
     * Cette mthode modifie le type du film.
     *
     * @param type le nouveau type du film
     */
    public final void setTheType(TypeImpl type) {
        this.type = type;
    }

    /**
     * Cette mthode retourne le type du film.
     *
     * @return Le type du film
     */
    public final TypeImpl getTheType() {
        return type;
    }

    /**
     * Cette mthode modifie l'anne du film.
     *
     * @param annee la nouvelle anne du film
     */
    public final void setYear(int annee) {
        year = annee;
    }

    /**
     * Cette mthode retourne l'anne du film.
     *
     * @return L'anne du film
     */
    public final int getYear() {
        return year;
    }

    /**
     * Cette mthode modifie la dure du film.
     *
     * @param duree la nouvelle dure du film
     */
    public final void setDuration(int duree) {
        duration = duree;
    }

    /**
     * Cette mthode retourne la dure du film.
     *
     * @return La dure du film
     */
    public final int getDuration() {
        return duration;
    }

    /**
     * Cette mthode modifie le ralisateur du film.
     *
     * @param realisateur le nouveau ralisateur
     */
    public final void setTheRealizer(RealizerImpl realisateur) {
        realizer = realisateur;
    }

    /**
     * Cette mthode retourne le ralisateur du film.
     *
     * @return Le rasaliteur du film
     */
    public final RealizerImpl getTheRealizer() {
        return realizer;
    }

    /**
     * Cette mthode modifie la langue du film.
     *
     * @param langue la nouvelle langue du film
     */
    public final void setTheLanguage(LanguageImpl langue) {
        language = langue;
    }

    /**
     * Cette mthode retourne la langue du film.
     *
     * @return La langue du film
     */
    public final LanguageImpl getTheLanguage() {
        return language;
    }

    @Override
    public final void setNote(Note note) {
        this.note = note;
    }

    @Override
    public final Note getNote() {
        return note;
    }

    /**
     * Cette mthode permet de modifier le commentaire du film.
     *
     * @param commentaire Le nouveau commentaire
     */
    public final void setComment(String commentaire) {
        comment = commentaire;
    }

    /**
     * Cette mthode retourne le commentaire sur le film.
     *
     * @return Le commentaire sur le film
     */
    public final String getComment() {
        return comment;
    }

    /**
     * Cette mthode modifie le rsum du film.
     *
     * @param resume Le nouveau rsum
     */
    public final void setResume(String resume) {
        this.resume = resume;
    }

    /**
     * Cette mthode retourne le rsum du film.
     *
     * @return Le rsum
     */
    public final String getResume() {
        return resume;
    }

    /**
     * Cette mthode modifie le chemin de l'image du film.
     *
     * @param imagePath Le nouveau chemin
     */
    public final void setImage(String imagePath) {
        image = imagePath;
    }

    /**
     * Cette mthode retourne le chemin vers le film.
     *
     * @return Le chemin vers le film
     */
    public final String getImage() {
        return image;
    }

    /**
     * Return the path to the file.
     *
     * @return The path to the file.
     */
    public final String getFilePath() {
        return filePath;
    }

    /**
     * Set the file path.
     *
     * @param filePath The path to the file.
     */
    public final void setFilePath(String filePath) {
        this.filePath = filePath;
    }

    /**
     * Cette mthode permet de rcuprer la liste des acteurs du film.
     *
     * @return La liste des acteurs du film
     */
    public final Set<ActorImpl> getActors() {
        return actors;
    }

    /**
     * Cette mthode permet de modifier les acteurs d'un film.
     *
     * @param acteurs La nouvelle liste d'acteurs du film
     */
    public final void setActors(Set<ActorImpl> acteurs) {
        actors = new HashSet<ActorImpl>(acteurs);
    }

    /**
     * Return all the kinds of the film.
     *
     * @return A List containing all the kinds of the film.
     */
    public final Set<KindImpl> getKinds() {
        return kinds;
    }

    /**
     * Set the kinds of the film.
     *
     * @param kinds The kinds of the film.
     */
    public final void setKinds(Set<KindImpl> kinds) {
        this.kinds = new HashSet<KindImpl>(kinds);
    }

    /**
     * Cette mthode permet de modifier l'emprunt du film.
     *
     * @param emprunt Le nouvel emprunt
     */
    public final void setTheLending(LendingImpl emprunt) {
        lending = emprunt;
    }

    /**
     * Cette mthode retourne l'emprunt d'un film.
     *
     * @return L'emprunt ou null
     */
    public final LendingImpl getTheLending() {
        return lending;
    }

    /**
     * Return the saga of the film.
     *
     * @return The saga of the film.
     */
    public final SagaImpl getTheSaga() {
        return theSaga;
    }

    /**
     * Set the saga of the film.
     *
     * @param theSaga The saga of the film.
     */
    public final void setTheSaga(SagaImpl theSaga) {
        this.theSaga = theSaga;
    }
}