package org.jtheque.films.services.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.films.persistence.dao.able.IDaoRealizers;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.services.able.INotesService;
import org.jtheque.films.services.able.IRealizersService;
import org.jtheque.primary.services.able.ICountriesService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * The implementation of the realizers service.
 *
 * @author Baptiste Wicht
 */
@Service
public final class RealizersService implements IRealizersService {
    @Resource
    private IDaoRealizers daoRealizers;

    @Resource
    private INotesService notesService;

    @Resource
    private ICountriesService countriesService;

    /* Variables */
    private RealizerImpl emptyRealizer;
    private RealizerImpl defaultRealizer;

    private static final String DEFAULT_REALIZER = "Inconnu";

    @Override
    public List<RealizerImpl> getRealizers() {
        return daoRealizers.getRealizers();
    }

    @Override
    @Transactional
    public boolean delete(RealizerImpl realizer) {
        return daoRealizers.delete(realizer);
    }

    @Override
    public boolean exists(String firstname, String name) {
        return daoRealizers.exists(firstname, name);
    }

    @Override
    public RealizerImpl getRealizer(String firstname, String name) {
        return daoRealizers.getRealizer(firstname, name);
    }

    @Override
    @Transactional
    public void create(RealizerImpl realizer) {
        daoRealizers.create(realizer);
    }

    @Override
    public boolean exists(RealizerImpl realizer) {
        return daoRealizers.exist(realizer);
    }

    @Override
    public boolean hasNoRealizers() {
        return daoRealizers.getRealizers().isEmpty();
    }

    @Override
    @Transactional
    public void save(RealizerImpl realizer) {
        daoRealizers.save(realizer);
    }

    @Override
    public List<RealizerImpl> getDatas() {
        return daoRealizers.getRealizers();
    }

    @Override
    public void addDataListener(DataListener listener) {
        daoRealizers.addDataListener(listener);
    }

    @Override
    public RealizerImpl getEmptyRealizer() {
        if (emptyRealizer == null) {
            emptyRealizer = new RealizerImpl();

            emptyRealizer.setName("");
            emptyRealizer.setFirstName("");
            emptyRealizer.setNote(notesService.getDefaultNote());
            emptyRealizer.setTheCountry(countriesService.getDefaultCountry());
        }

        return emptyRealizer;
    }

    @Override
    @Transactional
    public RealizerImpl getDefaultRealizer() {
        if (defaultRealizer == null) {
            defaultRealizer = daoRealizers.getRealizer(DEFAULT_REALIZER, DEFAULT_REALIZER);

            if (defaultRealizer == null) {
                defaultRealizer = new RealizerImpl();

                defaultRealizer.setName(DEFAULT_REALIZER);
                defaultRealizer.setFirstName(DEFAULT_REALIZER);
                defaultRealizer.setNote(notesService.getDefaultNote());
                defaultRealizer.setTheCountry(countriesService.getDefaultCountry());
                daoRealizers.create(defaultRealizer);
            }
        }

        return defaultRealizer;
    }

    @Override
    @Transactional
    public void clearAll() {
        daoRealizers.clearAll();
    }

    @Override
    public String getDataType() {
        return DATA_TYPE;
    }
}