package org.jtheque.films.services.impl.utils.file.exports;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JRExporterParameter;
import net.sf.jasperreports.engine.JasperCompileManager;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.JasperReport;
import net.sf.jasperreports.engine.design.JasperDesign;
import net.sf.jasperreports.engine.export.JRTextExporter;
import net.sf.jasperreports.engine.export.JRTextExporterParameter;
import net.sf.jasperreports.engine.xml.JRXmlLoader;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.log.ILoggingManager;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.services.impl.utils.search.Search;
import org.jtheque.films.utils.Constants.Files.FileType;
import org.jtheque.films.utils.Constants.Report;
import org.jtheque.films.utils.ReportUtils;

/**
 * An exporter to plain text file.
 *
 * @author Baptiste Wicht
 */
public class TexteExporter extends AbstractExporter {
    @Override
    public boolean canExportTo(FileType fileType) {
        return fileType == FileType.TXT;
    }

    @Override
    @SuppressWarnings("unchecked")
    public void export(String path) {
        Search<FilmImpl> search = (Search<FilmImpl>) getSearch();

        try {
            JasperDesign jasperDesign = JRXmlLoader.load(getClass().getClassLoader().getResourceAsStream(Report.FORM001_TEXT));
            JasperReport jasperReport = JasperCompileManager.compileReport(jasperDesign);

            JasperPrint jasperPrint = ReportUtils.configureForm001(jasperReport, search.getResults());

            JRTextExporter textExporter = new JRTextExporter();
            textExporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
            textExporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME, path);
            textExporter.setParameter(JRTextExporterParameter.CHARACTER_WIDTH, 10);
            textExporter.setParameter(JRTextExporterParameter.CHARACTER_HEIGHT, 10);
            textExporter.exportReport();
        } catch (JRException e) {
            Managers.getManager(ILoggingManager.class).getLogger(getClass()).exception(e);
        }
    }
}