package org.jtheque.films.services.impl.utils.file.exports;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdom.Document;
import org.jdom.Element;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.utils.file.XMLUtils;
import org.jtheque.utils.bean.IntDate;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.services.impl.utils.search.Search;
import org.jtheque.films.utils.Constants;
import org.jtheque.films.utils.Constants.Files.FileType;
import org.jtheque.primary.od.KindImpl;

/**
 * An exporter to XML.
 *
 * @author Baptiste Wicht
 */
public final class XMLExporter extends AbstractExporter {
    @Override
    public boolean canExportTo(FileType fileType) {
        return fileType == FileType.XML;
    }

    @Override
    public void export(String path) {
        Search<FilmImpl> search = (Search<FilmImpl>) getSearch();

        Element racine = new Element("films");

        Document doc = new Document(racine);

        Element header = new Element("header");

        Element date = new Element("date");
        date.setText(Integer.toString(IntDate.today().intValue()));
        header.addContent(date);

        Element fileVersion = new Element("file-version");
        fileVersion.setText(Integer.toString(Constants.Files.Versions.XML.THIRD));
        header.addContent(fileVersion);

        Element jthequeVersion = new Element("jtheque-version");
        jthequeVersion.setText(Managers.getCore().getApplication().getVersion().getVersion());
        header.addContent(jthequeVersion);

        racine.addContent(header);

        for (FilmImpl film : search.getResults()) {
            Element filmElement = new Element("film");

            Element titreElement = new Element("title");
            titreElement.setText(film.getTitle());
            filmElement.addContent(titreElement);

            exportActors(film, filmElement);

            exportKinds(film, filmElement);

            Element elementAnnee = new Element("year");
            elementAnnee.setText(Integer.toString(film.getYear()));
            filmElement.addContent(elementAnnee);

            exportRealizer(film, filmElement);

            if (film.hasType()) {
                Element elementType = new Element("type");
                elementType.setText(film.getTheType().getName());
                filmElement.addContent(elementType);
            }

            if (film.hasLanguage()) {
                Element elementLangue = new Element("language");
                elementLangue.setText(film.getTheLanguage().getName());
                filmElement.addContent(elementLangue);
            }

            Element elementDuree = new Element("duration");
            elementDuree.setText(String.valueOf(film.getDuration()));
            filmElement.addContent(elementDuree);

            Element elementNote = new Element("note");
            elementNote.setText(String.valueOf(film.getNote().getValue()));
            filmElement.addContent(elementNote);

            Element elementResume = new Element("resume");
            elementResume.setText(film.getResume());
            filmElement.addContent(elementResume);

            Element elementCommentaire = new Element("comment");
            elementCommentaire.setText(film.getComment());
            filmElement.addContent(elementCommentaire);

            racine.addContent(filmElement);
        }

        XMLUtils.writeXml(doc, path);
    }

    private void exportActors(FilmImpl film, Element filmElement) {
        Element acteursElement = new Element("actors");

        for (ActorImpl acteur : film.getActors()) {
            Element elementActeur = new Element("actor");

            Element elementActorName = new Element("name");
            elementActorName.setText(acteur.getName());
            elementActeur.addContent(elementActorName);

            Element elementActorFirstName = new Element("firstname");
            elementActorFirstName.setText(acteur.getFirstName());
            elementActeur.addContent(elementActorFirstName);

            Element elementCountry = new Element("country");
            elementCountry.setText(acteur.getTheCountry().getAffichableText());
            elementActeur.addContent(elementCountry);

            acteursElement.addContent(elementActeur);
        }

        filmElement.addContent(acteursElement);
    }

    private void exportKinds(FilmImpl film, Element filmElement) {
        Element kindsElement = new Element("kinds");

        if (film.hasKinds()) {
            for (KindImpl kind : film.getKinds()) {
                Element kindElement = new Element("kind");

                Element elementKindName = new Element("name");
                elementKindName.setText(kind.getName());
                kindElement.addContent(elementKindName);

                kindsElement.addContent(kindElement);
            }
        }

        filmElement.addContent(kindsElement);
    }

    private void exportRealizer(FilmImpl film, Element filmElement) {
        if (film.hasRealizer()) {
            Element elementRealisateur = new Element("realizer");

            Element elementRealizerName = new Element("name");
            elementRealizerName.setText(film.getTheRealizer().getName());
            elementRealisateur.addContent(elementRealizerName);

            Element elementRealizerFirstName = new Element("firstname");
            elementRealizerFirstName.setText(film.getTheRealizer().getFirstName());
            elementRealisateur.addContent(elementRealizerFirstName);

            Element elementCountry = new Element("country");
            elementCountry.setText(film.getTheRealizer().getTheCountry().getAffichableText());
            elementRealisateur.addContent(elementCountry);

            filmElement.addContent(elementRealisateur);
        }
    }
}