package org.jtheque.films.services.impl.utils.file.jt;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.utils.file.jt.AbstractJTFileHeader;
import org.jtheque.core.utils.file.jt.able.JTNotZippedFile;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.services.impl.utils.file.jt.header.JTFFileHeader;
import org.jtheque.primary.od.CountryImpl;
import org.jtheque.primary.od.LanguageImpl;
import org.jtheque.primary.od.TypeImpl;
import org.jtheque.primary.od.KindImpl;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Cette classe reprsente un fichier JTF et toutes ses caractristiques.
 *
 * @author Baptiste Wicht
 */
public final class JTFFile implements JTNotZippedFile {
    /* Datas of the film */
    private FilmImpl film;
    private Set<ActorImpl> acteurs;
    private Set<KindImpl> kinds;
    private RealizerImpl realisateur;
    private LanguageImpl langue;
    private TypeImpl type;
    private List<CountryImpl> countries;

    //Corrects separators
    private boolean correctSeparators = true;

    //Header
    private AbstractJTFileHeader header;

    /**
     * Construct a new JTFEFile.
     */
    public JTFFile() {
        super();

        setHeader(new JTFFileHeader());
    }

    @Override
    public AbstractJTFileHeader getHeader() {
        return header;
    }

    @Override
    public boolean isValid() {
        return film != null && getHeader().isComplete() && isCorrectSeparators();
    }

    @Override
    public boolean isCorrectSeparators() {
        return correctSeparators;
    }

    @Override
    public void setCorrectSeparators(boolean correctSeparators) {
        this.correctSeparators = correctSeparators;
    }

    /**
     * Return the actors of the file.
     *
     * @return The actors of the file.
     */
    public Set<ActorImpl> getActeurs() {
        return acteurs;
    }

    /**
     * Set the actors of the file.
     *
     * @param acteurs The actors of the file.
     */
    public void setActeurs(Set<ActorImpl> acteurs) {
        this.acteurs = new HashSet<ActorImpl>(acteurs);
    }

    /**
     * Return the kinds of the file.
     *
     * @return A list containing all the kinds of the file.
     */
    public Set<KindImpl> getKinds() {
        return kinds;
    }

    /**
     * Set the kinds of the file.
     *
     * @param kinds The kinds of the file.
     */
    public void setKinds(Set<KindImpl> kinds) {
        this.kinds = new HashSet<KindImpl>(kinds);
    }

    /**
     * Return the film.
     *
     * @return The film of the file.
     */
    public FilmImpl getFilm() {
        return film;
    }

    /**
     * Set the film.
     *
     * @param film The film.
     */
    public void setFilm(FilmImpl film) {
        this.film = film;
    }

    /**
     * Return the language.
     *
     * @return The language.
     */
    public LanguageImpl getLangue() {
        return langue;
    }

    /**
     * Set the language.
     *
     * @param langue The language.
     */
    public void setLangue(LanguageImpl langue) {
        this.langue = langue;
    }

    /**
     * Return the countries.
     *
     * @return The countries.
     */
    public Iterable<CountryImpl> getCountries() {
        return countries;
    }

    /**
     * Set the countries.
     *
     * @param countries The countries.
     */
    public void setCountries(List<CountryImpl> countries) {
        this.countries = new ArrayList<CountryImpl>(countries);
    }

    /**
     * Return the realizer.
     *
     * @return The realizer.
     */
    public RealizerImpl getRealizer() {
        return realisateur;
    }

    /**
     * Set the realizer.
     *
     * @param realisateur The realizer.
     */
    public void setRealisateur(RealizerImpl realisateur) {
        this.realisateur = realisateur;
    }

    /**
     * Return the type.
     *
     * @return The type.
     */
    public TypeImpl getType() {
        return type;
    }

    /**
     * Set the type.
     *
     * @param type The type.
     */
    public void setType(TypeImpl type) {
        this.type = type;
    }

    /**
     * Set the header.
     *
     * @param header The header.
     */
    private void setHeader(AbstractJTFileHeader header) {
        this.header = header;
    }
}