package org.jtheque.films.services.impl.utils.search;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.utils.db.Note;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.primary.od.LanguageImpl;
import org.jtheque.primary.od.KindImpl;
import org.jtheque.primary.od.TypeImpl;

/**
 * A search of films.
 *
 * @author Baptiste Wicht
 */
public final class FilmSearch extends AbstractSearch<FilmImpl> {
    private boolean mustCheckKind;
    private boolean mustCheckActor;
    private boolean mustCheckType;
    private boolean mustCheckYear;
    private boolean mustCheckRealizer;
    private boolean mustCheckLanguage;
    private boolean mustCheckNote;
    private boolean mustCheckDuration;

    /* Search's criteria */
    private KindImpl kind;
    private ActorImpl actor;
    private TypeImpl type;
    private int startYear;
    private int endYear;
    private RealizerImpl realizer;
    private LanguageImpl language;
    private Note note;
    private int startDuration;
    private int endDuration;

    /**
     * Construct a new <code>FilmSearch</code>.
     */
    public FilmSearch() {
        super();

        setSearcher(new FilmSearcher());
    }

    /**
     * Return the actor of the search.
     *
     * @return The actor of the search.
     */
    public ActorImpl getActor() {
        return actor;
    }

    /**
     * Set the actor of the search.
     *
     * @param actor The actor of the search.
     */
    public void setActor(ActorImpl actor) {
        this.actor = actor;
    }

    /**
     * Return the end year of the search.
     *
     * @return The end year of the search.
     */
    public int getEndYear() {
        return endYear;
    }

    /**
     * Set the end year of the search.
     *
     * @param anneeA The end year of the search.
     */
    public void setEndYear(int anneeA) {
        endYear = anneeA;
    }


    /**
     * Return the end year of the search.
     *
     * @return The start year of the search.
     */
    public int getStartYear() {
        return startYear;
    }

    /**
     * Set the start year of the search.
     *
     * @param anneeDe The start year of the search.
     */
    public void setStartYear(int anneeDe) {
        startYear = anneeDe;
    }

    /**
     * Return the end duration of the search.
     *
     * @return The end duration of the search.
     */
    public int getEndDuration() {
        return endDuration;
    }

    /**
     * Set the end duration of the search.
     *
     * @param dureeA The end duration of the search.
     */
    public void setEndDuration(int dureeA) {
        endDuration = dureeA;
    }

    /**
     * Return the start duration of the search.
     *
     * @return The start duration of the search.
     */
    public int getStartDuration() {
        return startDuration;
    }

    /**
     * Set the start duration of the search.
     *
     * @param dureeDe The start duration of the search.
     */
    public void setStartDuration(int dureeDe) {
        startDuration = dureeDe;
    }

    /**
     * Return the kind of the search.
     *
     * @return The kind of the search.
     */
    public KindImpl getKind() {
        return kind;
    }

    /**
     * Set the kind of the search.
     *
     * @param kind The kind of the search.
     */
    public void setKind(KindImpl kind) {
        this.kind = kind;
    }

    /**
     * Return the language of the search.
     *
     * @return The language of the search.
     */
    public LanguageImpl getLanguage() {
        return language;
    }

    /**
     * Set the language of the search.
     *
     * @param language The language of the search.
     */
    public void setLanguage(LanguageImpl language) {
        this.language = language;
    }

    /**
     * Return the note of the search.
     *
     * @return The note of the search.
     */
    public Note getNote() {
        return note;
    }

    /**
     * Set the note of the search.
     *
     * @param note The note of the search.
     */
    public void setNote(Note note) {
        this.note = note;
    }

    /**
     * Return the realizer of the search.
     *
     * @return The realizer of the search.
     */
    public RealizerImpl getRealizer() {
        return realizer;
    }

    /**
     * Set the realizer of the search.
     *
     * @param realizer The realizer of the search.
     */
    public void setRealizer(RealizerImpl realizer) {
        this.realizer = realizer;
    }

    /**
     * Return the type of the search.
     *
     * @return The type of the search.
     */
    public TypeImpl getType() {
        return type;
    }

    /**
     * Set the type of the search.
     *
     * @param type The type of the search.
     */
    public void setType(TypeImpl type) {
        this.type = type;
    }

    /**
     * Indicate if we must check actor or not.
     *
     * @return true if we must check actor else false.
     */
    public boolean isMustCheckActor() {
        return mustCheckActor;
    }

    /**
     * Set boolean flag indicating if we must check actor or not.
     *
     * @param mustCheckActeur A boolean indicating if we must check actor or not.
     */
    public void setMustCheckActor(boolean mustCheckActeur) {
        mustCheckActor = mustCheckActeur;
    }

    /**
     * Indicate if we must check year or not.
     *
     * @return true if we must check year else false.
     */
    public boolean isMustCheckYear() {
        return mustCheckYear;
    }

    /**
     * Set boolean flag indicating if we must check year or not.
     *
     * @param mustCheckAnnee A boolean indicating if we must check year or not.
     */
    public void setMustCheckYear(boolean mustCheckAnnee) {
        mustCheckYear = mustCheckAnnee;
    }

    /**
     * Indicate if we must check duration or not.
     *
     * @return true if we must check duration else false.
     */
    public boolean isMustCheckDuration() {
        return mustCheckDuration;
    }

    /**
     * Set boolean flag indicating if we must check duration or not.
     *
     * @param mustCheckDuree A boolean indicating if we must check duration or not.
     */
    public void setMustCheckDuration(boolean mustCheckDuree) {
        mustCheckDuration = mustCheckDuree;
    }

    /**
     * Indicate if we must check kind or not.
     *
     * @return true if we must check kind else false.
     */
    public boolean isMustCheckKind() {
        return mustCheckKind;
    }

    /**
     * Set boolean flag indicating if we must check kind or not.
     *
     * @param mustCheckGenre A boolean indicating if we must check kind or not.
     */
    public void setMustCheckKind(boolean mustCheckGenre) {
        mustCheckKind = mustCheckGenre;
    }

    /**
     * Indicate if we must check language or not.
     *
     * @return true if we must check language else false.
     */
    public boolean isMustCheckLanguage() {
        return mustCheckLanguage;
    }

    /**
     * Set boolean flag indicating if we must check language or not.
     *
     * @param mustCheckLangue A boolean indicating if we must check language or not.
     */
    public void setMustCheckLanguage(boolean mustCheckLangue) {
        mustCheckLanguage = mustCheckLangue;
    }

    /**
     * Indicate if we must check note or not.
     *
     * @return true if we must check note else false.
     */
    public boolean isMustCheckNote() {
        return mustCheckNote;
    }

    /**
     * Set boolean flag indicating if we must check note or not.
     *
     * @param mustCheckNote A boolean indicating if we must check note or not.
     */
    public void setMustCheckNote(boolean mustCheckNote) {
        this.mustCheckNote = mustCheckNote;
    }

    /**
     * Indicate if we must check realizer or not.
     *
     * @return true if we must check realizer else false.
     */
    public boolean isMustCheckRealizer() {
        return mustCheckRealizer;
    }

    /**
     * Set boolean flag indicating if we must check realizer or not.
     *
     * @param mustCheckRealisateur A boolean indicating if we must check realizer or not.
     */
    public void setMustCheckRealizer(boolean mustCheckRealisateur) {
        mustCheckRealizer = mustCheckRealisateur;
    }

    /**
     * Indicate if we must check type or not.
     *
     * @return true if we must check type else false.
     */
    public boolean isMustCheckType() {
        return mustCheckType;
    }

    /**
     * Set boolean flag indicating if we must check type or not.
     *
     * @param mustCheckType A boolean indicating if we must check type or not.
     */
    public void setMustCheckType(boolean mustCheckType) {
        this.mustCheckType = mustCheckType;
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder("FilmSearch : \n");

        builder.append("Must : \n");
        builder.append("\t Acteur : ").append(mustCheckActor).append(" \n");
        builder.append("\t Year : ").append(mustCheckYear).append(" \n");
        builder.append("\t Duration : ").append(mustCheckDuration).append(" \n");
        builder.append("\t Kind : ").append(mustCheckKind).append(" \n");
        builder.append("\t Note : ").append(mustCheckNote).append(" \n");
        builder.append("\t Realizer : ").append(mustCheckRealizer).append(" \n");
        builder.append("\t Type : ").append(mustCheckType).append(" \n");
        builder.append("\t Language : ").append(mustCheckLanguage).append(" \n");

        builder.append("Values :  \n");
        builder.append("\t Acteur : ").append(actor).append(" \n");
        builder.append("\t Year From : ").append(startYear).append(" \n");
        builder.append("\t Year To : ").append(endYear).append(" \n");
        builder.append("\t Duration From : ").append(startDuration).append(" \n");
        builder.append("\t Duration To : ").append(endDuration).append(" \n");
        builder.append("\t Kind : ").append(kind).append(" \n");
        builder.append("\t Note : ").append(note).append(" \n");
        builder.append("\t Realizer : ").append(realizer).append(" \n");
        builder.append("\t Type : ").append(type).append(" \n");
        builder.append("\t Language : ").append(language).append(" \n");

        return builder.toString();
    }
}