package org.jtheque.films.services.impl.utils.search;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.log.ILoggingManager;
import org.jtheque.core.managers.beans.IBeansManager;
import org.jtheque.core.utils.db.EntityUtils;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.services.able.IFilmsService;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * A searcher for the films. This classe permit a search of films with an objet Search.
 *
 * @author Baptiste Wicht
 */
public final class FilmSearcher implements Searcher<FilmImpl> {
    @Resource
    private IFilmsService filmsService;

    /**
     * Construct a new FilmSearcher.
     */
    public FilmSearcher() {
        super();

        Managers.getManager(IBeansManager.class).inject(this);
    }

    @Override
    public List<FilmImpl> search(Search<FilmImpl> research) {
        List<FilmImpl> list = new ArrayList<FilmImpl>(20);
        FilmSearch search = (FilmSearch) research;

        for (FilmImpl film : filmsService.getFilms()) {
            boolean correct = true;

            if (search.isMustCheckActor() &&
                    !EntityUtils.containsID(film.getActors(), search.getActor().getId())) {
                correct = false;
            }

            if (search.isMustCheckKind() && !film.getKinds().contains(search.getKind())) {
                correct = false;
            }

            if (search.isMustCheckType() && !film.getTheType().equals(search.getType())) {
                correct = false;
            }

            if (search.isMustCheckYear()) {
                Managers.getManager(ILoggingManager.class).getLogger(getClass()).debug("Check annee");
                if (film.getYear() < search.getStartYear() || film.getYear() > search.getEndYear()) {
                    correct = false;
                    Managers.getManager(ILoggingManager.class).getLogger(getClass()).debug("Annee false");
                }
            }

            if (search.isMustCheckRealizer() && !film.getTheRealizer().equals(search.getRealizer())) {
                correct = false;
            }

            if (search.isMustCheckLanguage() && !film.getTheLanguage().equals(search.getLanguage())) {
                correct = false;
            }

            if (search.isMustCheckNote() && !film.getNote().equals(search.getNote())) {
                correct = false;
            }

            if (search.isMustCheckDuration() &&
                    (film.getDuration() < search.getStartDuration() ||
                            film.getDuration() > search.getEndDuration())) {
                correct = false;
            }

            if (correct) {
                list.add(film);
            }
        }

        return list;
    }
}