package org.jtheque.films.services.impl.utils.search;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.beans.IBeansManager;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.services.able.IRealizersService;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * A searcher for the realizers. This classe permit a search of realizers with an objet Search.
 *
 * @author Baptiste Wicht
 */
public final class RealizerSearcher implements Searcher<RealizerImpl> {
    @Resource
    private IRealizersService realizersService;

    /**
     * Construct a new RealizerSearcher.
     */
    public RealizerSearcher() {
        super();

        Managers.getManager(IBeansManager.class).inject(this);
    }

    @Override
    public List<RealizerImpl> search(Search<RealizerImpl> research) {
        List<RealizerImpl> realizers = realizersService.getRealizers();

        List<RealizerImpl> list = new ArrayList<RealizerImpl>(realizers.size() / 2);
        RealizerSearch search = (RealizerSearch) research;

        for (RealizerImpl realizer : realizers) {
            boolean correct = true;

            if (search.isMustCheckNote() && !realizer.getNote().equals(search.getNote())) {
                correct = false;
            }

            if (search.isMustCheckCountry() && !realizer.getTheCountry().equals(search.getCountry())) {
                correct = false;
            }

            if (correct) {
                list.add(realizer);
            }
        }

        return list;
    }
}