package org.jtheque.films.view.impl.choiceActions;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.undo.IUndoRedoManager;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.films.controllers.impl.undo.delete.DeletedActorEdit;
import org.jtheque.films.controllers.impl.undo.delete.DeletedBorrowerEdit;
import org.jtheque.films.controllers.impl.undo.delete.DeletedCountryEdit;
import org.jtheque.films.controllers.impl.undo.delete.DeletedFilmEdit;
import org.jtheque.films.controllers.impl.undo.delete.DeletedKindEdit;
import org.jtheque.films.controllers.impl.undo.delete.DeletedLanguageEdit;
import org.jtheque.films.controllers.impl.undo.delete.DeletedRealizerEdit;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.services.able.IFilmsService;
import org.jtheque.films.services.able.IRealizersService;
import org.jtheque.films.utils.Constants;
import org.jtheque.primary.od.*;
import org.jtheque.primary.services.able.*;
import org.jtheque.primary.view.impl.choice.AbstractChoiceAction;
import org.jtheque.primary.controller.impl.undo.DeletedTypeEdit;
import org.jtheque.primary.controller.impl.undo.DeletedSagaEdit;

import javax.annotation.Resource;

/**
 * An action to delete the selected item.
 *
 * @author Baptiste Wicht
 */
public final class DeleteChoiceAction extends AbstractChoiceAction {
    /* Entity managers */
    @Resource
    private IFilmsService filmsService;

    @Resource
    private ITypesService typesService;

    @Resource
    private IKindsService kindsService;

    @Resource
    private IBorrowersService borrowersService;

    @Resource
    private IActorService actorService;

    @Resource
    private ICountriesService countriesService;

    @Resource
    private ILanguagesService languagesService;

    @Resource
    private IRealizersService realizersService;

    @Resource
    private ISagasService sagasService;

    /* Singletons */
    private final ILanguageManager resources = Managers.getManager(ILanguageManager.class);

    @Override
    public boolean canDoAction(final String action) {
        return "delete".equals(action);
    }

    @Override
    public void execute() {
        final boolean yes = Managers.getManager(IViewManager.class).askUserForConfirmation(
                resources.getMessage("choice.dialogs.delete") + ' ' + getSelectedItem().toString(),
                resources.getMessage("choice.dialogs.delete.title"));

        if (yes) {
            delete();
        }
    }

    /**
     * Delete the selected item.
     */
    private void delete() {
        if (IFilmsService.DATA_TYPE.equals(getContent())) {
            boolean deleted = filmsService.delete((FilmImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedFilmEdit((FilmImpl) getSelectedItem()));
            }
        } else if (IActorService.DATA_TYPE.equals(getContent())) {
            boolean deleted = actorService.delete((ActorImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedActorEdit((ActorImpl) getSelectedItem()));
            }
        } else if (IKindsService.DATA_TYPE.equals(getContent())) {
            boolean deleted = kindsService.delete((KindImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedKindEdit((KindImpl) getSelectedItem()));
            }
        } else if (ITypesService.DATA_TYPE.equals(getContent())) {
            boolean deleted = typesService.delete((TypeImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedTypeEdit((TypeImpl) getSelectedItem()));
            }
        } else if (ILanguagesService.DATA_TYPE.equals(getContent())) {
            boolean deleted = languagesService.delete((LanguageImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedLanguageEdit((LanguageImpl) getSelectedItem()));
            }
        } else if (IRealizersService.DATA_TYPE.equals(getContent())) {
            boolean deleted = realizersService.delete((RealizerImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedRealizerEdit((RealizerImpl) getSelectedItem()));
            }
        } else if (ICountriesService.DATA_TYPE.equals(getContent())) {
            boolean deleted = countriesService.delete((CountryImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedCountryEdit((CountryImpl) getSelectedItem()));
            }
        } else if (Constants.BORROWERS.equals(getContent())) {
            boolean deleted = borrowersService.delete((BorrowerImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedBorrowerEdit((BorrowerImpl) getSelectedItem()));
            }
        } else if (ISagasService.DATA_TYPE.equals(getContent())) {
            boolean deleted = sagasService.delete((SagaImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedSagaEdit((SagaImpl) getSelectedItem()));
            }
        }
    }
}