package org.jtheque.films.view.impl.frames;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.managers.view.impl.actions.JThequeSimpleAction;
import org.jtheque.core.utils.ui.ValidationUtils;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.utils.ui.GridBagUtils;
import org.jtheque.films.services.impl.utils.web.FilmResult;
import org.jtheque.films.utils.Constants.Properties.Film;
import org.jtheque.films.utils.Constants.Site;
import org.jtheque.films.view.able.IAutoAddView;
import org.jtheque.films.view.impl.models.AutoAddModel;
import org.jtheque.films.view.impl.models.list.SitesListModel;

import javax.swing.DefaultListModel;
import javax.swing.JList;
import javax.swing.JTextField;
import javax.swing.ListSelectionModel;
import javax.annotation.PostConstruct;

import java.awt.Container;
import java.awt.Frame;
import java.util.List;

/**
 * Cette classe est l'interface graphique qui permet d'ajouter des films automatiquement.
 *
 * @author Baptiste Wicht
 */
public final class AutoAddView extends SwingDialogView implements IAutoAddView {
    private static final long serialVersionUID = 4633039680922071605L;

    private JTextField fieldTitle;
    private JList listSites;
    private JList listFilms;

    private DefaultListModel modelListFilms;

    private int phase = PHASE_1;

    private JThequeSimpleAction chooseSiteAction;
    private JThequeAction closeViewAction;
    private JThequeAction displayInfosAboutSiteAction;
    private JThequeAction validateViewAction;
    
    /**
     * Construct a new JFrameAutoAdd.
     * 
     * @param parent The parent frame. 
     */
    public AutoAddView(Frame parent) {
        super(parent);
    }

    @Override
    @PostConstruct
    public void build() {
        setTitleKey("auto.add.view.title");
        setContentPane(buildContentPane());
        setResizable(true);
        pack();

        SwingUtils.centerFrame(this);
    }

    /**
     * Cette mthode initialise et retourne le contentPane de la fentre.
     *
     * @return Le contentPane
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();

        builder.addI18nLabel(Film.TITLE, builder.gbcSet(0, 0));
        
        fieldTitle = builder.add(new JTextField(), builder.gbcSet(1, 0));
        SwingUtils.addFieldValidateAction(fieldTitle, chooseSiteAction);

        addListsPanel(builder);

        builder.addButtonBar(builder.gbcSet(0, 2, GridBagUtils.HORIZONTAL, GridBagUtils.BASELINE_LEADING, 2, 1), 
                displayInfosAboutSiteAction, validateViewAction, closeViewAction);

        return builder.getPanel();
    }

    private void addListsPanel(PanelBuilder parent) {
        PanelBuilder builder = parent.addPanel(parent.gbcSet(0, 1, GridBagUtils.BOTH, GridBagUtils.BASELINE_LEADING, 2, 1));
        
        listSites = new JList(new SitesListModel());
        listSites.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        
        builder.addScrolled(listSites, builder.gbcSet(0, 0, GridBagUtils.BOTH));

        builder.addButton(chooseSiteAction, builder.gbcSet(1, 0));

        modelListFilms = new DefaultListModel();

        listFilms = new JList(modelListFilms);
        listFilms.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        
        builder.addScrolled(listFilms, builder.gbcSet(2, 0, GridBagUtils.BOTH));
    }

    @Override
    public void sendMessage(String message, Object value) {
        if ("title".equals(message)) {
            fieldTitle.setText((String) value);
        }
    }

    @Override
    public JTextField getFieldTitle() {
        return fieldTitle;
    }

    @Override
    public DefaultListModel getModelListFilms() {
        return modelListFilms;
    }

    @Override
    public Site getSelectedSite() {
        return (Site) listSites.getSelectedValue();
    }

    @Override
    public FilmResult getSelectedFilm() {
        return getModel().getResults().get(listFilms.getSelectedIndex());
    }

    @Override
    public AutoAddModel getModel() {
        return (AutoAddModel) super.getModel();
    }

    @Override
    public boolean validateContent(int phase) {
        this.phase = phase;

        return validateContent();
    }

    @Override
    protected void validate(List<JThequeError> errors) {
        if (PHASE_1 == phase) {
            ValidationUtils.rejectIfEmpty(fieldTitle.getText(), "auto.view.title.film", errors);
            ValidationUtils.rejectIfNothingSelected(listSites, "auto.view.site", errors);
        } else if (PHASE_2 == phase) {
            ValidationUtils.rejectIfNothingSelected(listFilms, "auto.add.view.title.film", errors);
        }
    }

    public void setChooseSiteAction(JThequeSimpleAction chooseSiteAction) {
        this.chooseSiteAction = chooseSiteAction;
    }

    public void setCloseViewAction(JThequeAction closeViewAction) {
        this.closeViewAction = closeViewAction;
    }

    public void setDisplayInfosAboutSiteAction(JThequeAction displayInfosAboutSiteAction) {
        this.displayInfosAboutSiteAction = displayInfosAboutSiteAction;
    }

    public void setValidateViewAction(JThequeAction validateViewAction) {
        this.validateViewAction = validateViewAction;
    }
}