package org.jtheque.films.view.impl.models;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.Entity;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.primary.view.impl.listeners.ObjectChangedEvent;
import org.jtheque.primary.view.impl.models.PrincipalDataModel;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;

import java.util.Collection;
import java.util.List;

/**
 * A model for the actors view.
 *
 * @author Baptiste Wicht
 */
public final class ActorsModel extends PrincipalDataModel {
    private List<ActorImpl> displayList;

    private ActorImpl currentActor;

    @Resource
    private IActorService actorService;

    @PostConstruct
    private void init(){
        actorService.addDataListener(this);
    }
    
    @Override
    @SuppressWarnings("unchecked")
    public void updateDisplayList(List<? extends Entity> datas) {
        getDisplayList().clear();

        Collection<ActorImpl> actors = (Collection<ActorImpl>) datas;

        if (actors == null) {
            getDisplayList().addAll(actorService.getActors());
        } else {
            getDisplayList().addAll(actors);
        }

        fireDisplayListChanged();
    }

    @Override
    public void updateDisplayList() {
        updateDisplayList(null);
    }

    /**
     * Return the display list.
     *
     * @return The display list
     */
    public List<ActorImpl> getDisplayList() {
        if (displayList == null) {
            displayList = actorService.getActors();
        }

        return displayList;
    }

    /**
     * Return the current actor.
     *
     * @return The current actor.
     */
    public ActorImpl getCurrentActor() {
        return currentActor;
    }

    /**
     * Set the current actor.
     *
     * @param actor The new current actor to set.
     */
    public void setCurrentActor(ActorImpl actor) {
        currentActor = actor;

        fireCurrentObjectChanged(new ObjectChangedEvent(this, currentActor));
    }
}