package org.jtheque.films.view.impl.models;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.Entity;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.services.able.IRealizersService;
import org.jtheque.primary.view.impl.listeners.ObjectChangedEvent;
import org.jtheque.primary.view.impl.models.PrincipalDataModel;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;

import java.util.Collection;
import java.util.List;

/**
 * A model for the realizers view.
 *
 * @author Baptiste Wicht
 */
public final class RealizersModel extends PrincipalDataModel {
    private List<RealizerImpl> displayList;

    private RealizerImpl currentRealizer;

    @Resource
    private IRealizersService realizersService;

    @PostConstruct
    public void init() {
        realizersService.addDataListener(this);
    }

    @Override
    @SuppressWarnings("unchecked")
    public void updateDisplayList(List<? extends Entity> datas) {
        getDisplayList().clear();

        Collection<RealizerImpl> realizers = (Collection<RealizerImpl>) datas;

        if (realizers != null) {
            getDisplayList().addAll(realizers);
        } else {
            getDisplayList().addAll(realizersService.getRealizers());
        }

        fireDisplayListChanged();
    }

    @Override
    public void updateDisplayList() {
        updateDisplayList(null);
    }

    /**
     * Return the display list.
     *
     * @return The display list
     */
    public List<RealizerImpl> getDisplayList() {
        if (displayList == null) {
            displayList = realizersService.getRealizers();
        }

        return displayList;
    }

    /**
     * Return the current realizer.
     *
     * @return The current realizer.
     */
    public RealizerImpl getCurrentRealizer() {
        return currentRealizer;
    }

    /**
     * Set the current realizer.
     *
     * @param realizer The new current realizer.
     */
    public void setCurrentRealizer(RealizerImpl realizer) {
        currentRealizer = realizer;

        fireCurrentObjectChanged(new ObjectChangedEvent(this, currentRealizer));
    }
}