package org.jtheque.films.view.impl.panels;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXPanel;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.persistence.DataEvent;
import org.jtheque.core.managers.persistence.able.DataContainer;
import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.core.managers.persistence.able.DataContainerProvider;
import org.jtheque.core.managers.view.impl.actions.JThequeSimpleAction;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.films.persistence.od.abstraction.Film;
import org.jtheque.films.view.able.IInfosKindsView;
import org.jtheque.films.view.impl.fb.FilmFormBean;
import org.jtheque.films.view.impl.models.list.DataContainerListModel;
import org.jtheque.films.view.impl.models.list.SimpleModel;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.primary.view.impl.listeners.ObjectChangedEvent;
import org.jtheque.primary.od.KindImpl;
import org.jtheque.primary.services.able.IKindsService;
import org.jtheque.utils.ui.GridBagUtils;

import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JList;
import javax.swing.ListSelectionModel;
import javax.swing.JComponent;
import javax.annotation.PostConstruct;
import javax.annotation.Resource;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @author Baptiste Wicht
 */
public final class JPanelInfosKinds extends JXPanel implements DataListener, IInfosKindsView {
    private static final long serialVersionUID = 447863972139498415L;

    private JButton buttonAdd;
    private JButton buttonRemove;
    private JButton buttonNew;
    private JList listKinds;
    private JList listKindsForFilm;
    
    private DataContainerListModel<KindImpl> kindsModel;
    private SimpleModel<KindImpl> kindsForFilmModel;
    
    private JThequeSimpleAction removeAction;
    private JThequeSimpleAction addAction;
    private JThequeAction newAction;
    
    @Resource
    private IKindsService kindsService;

    /**
     * Build the view.
     */
    @PostConstruct
    private void build() {
        PanelBuilder builder = new PanelBuilder(this);
    
        kindsModel = new DataContainerListModel<KindImpl>(kindsService);

        DataContainerProvider.getInstance().getContainerForDataType(IKindsService.DATA_TYPE).addDataListener(this);
        
        listKinds = builder.addList(kindsModel, null, 
                builder.gbcSet(0, 0, GridBagUtils.BOTH, GridBagUtils.ABOVE_BASELINE_LEADING, 1, 0, 0.5, 1.0));
        listKinds.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);

        buttonAdd = builder.addButton(addAction, builder.gbcSet(1, 0));
        buttonAdd.setEnabled(false);

        buttonRemove = builder.addButton(removeAction, builder.gbcSet(1, 1));
        buttonRemove.setEnabled(false);

        buttonNew = builder.addButton(newAction, builder.gbcSet(1, 2));
        buttonNew.setEnabled(false);
        
        kindsForFilmModel = new SimpleModel<KindImpl>();
        
        listKindsForFilm = builder.addList(kindsForFilmModel, null, 
                builder.gbcSet(2, 0, GridBagUtils.BOTH, GridBagUtils.ABOVE_BASELINE_LEADING, 1, 0, 0.5, 1.0));
        listKindsForFilm.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        
    }

    @Override
    public void objectChanged(ObjectChangedEvent event) {
        kindsForFilmModel.removeAllElements();
        kindsModel.reload();

        Set<KindImpl> kinds = ((Film) event.getObject()).getKinds();

        for (KindImpl kind : kinds) {
            kindsModel.removeElement(kind);
            kindsForFilmModel.addElement(kind);
        }
    }

    @Override
    public void fillFilm(FilmFormBean fb) {
        if (kindsForFilmModel.getSize() != 0) {
            fb.setKinds(new HashSet<KindImpl>(kindsForFilmModel.getObjects()));
        }
    }

    @Override
    public void setEnabled(boolean enabled) {
        buttonAdd.setEnabled(enabled);
        buttonRemove.setEnabled(enabled);
        buttonNew.setEnabled(enabled);

        super.setEnabled(enabled);
    }

    @Override
    public DefaultListModel getKindsModel() {
        return kindsModel;
    }

    @Override
    public DefaultListModel getKindsForFilmModel() {
        return kindsForFilmModel;
    }

    @Override
    public int[] getSelectedKindsIndices() {
        return listKinds.getSelectedIndices();
    }

    @Override
    public int[] getSelectedKindsForFilmIndices() {
        return listKindsForFilm.getSelectedIndices();
    }

    @Override
    public void validate(List<JThequeError> errors) {
    }

    @Override
    public void dataChanged(DataEvent e) {
        for (KindImpl o : kindsForFilmModel.getObjects()) {
            kindsModel.removeElement(o);
        }
    }

    public void setRemoveAction(JThequeSimpleAction removeAction) {
        this.removeAction = removeAction;
    }

    public void setAddAction(JThequeSimpleAction addAction) {
        this.addAction = addAction;
    }

    public void setNewAction(JThequeAction newAction) {
        this.newAction = newAction;
    }

    @Override
    public JComponent getImpl() {
        return this;
    }
}