package org.jtheque.films.view.impl.sort;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.services.able.IFilmsService;
import org.jtheque.films.utils.Constants;
import org.jtheque.films.controllers.able.IFilmController;
import org.jtheque.primary.view.impl.models.tree.Category;
import org.jtheque.primary.view.impl.models.tree.JThequeTreeModel;
import org.jtheque.primary.view.impl.models.tree.RootElement;
import org.jtheque.primary.view.impl.sort.Sorter;

import javax.annotation.Resource;

import java.util.HashMap;
import java.util.Map;

/**
 * Cette classe permet de raliser un tri par anne.
 *
 * @author Baptiste Wicht
 */
public final class ByYearSorter implements Sorter {
    @Resource
    private IFilmController filmController;

    @Override
    public boolean canSort(final String content, final String sortType) {
        return content.equals(IFilmsService.DATA_TYPE) && sortType.equals(Constants.YEAR);
    }

    @Override
    public void sort(JThequeTreeModel model) {
        RootElement root = model.getRoot();

        Map<Integer, Category> groups = new HashMap<Integer, Category>(10);
        
        for (FilmImpl film : filmController.getDisplayList()) {
            int annee = film.getYear();

            if (!groups.containsKey(annee)) {
                Category category = new Category(Integer.toString(annee));

                root.addCategory(category);
                groups.put(annee, category);
            }

            groups.get(annee).addElement(film);
        }

        model.setRootElement(root);
    }
}