package org.jtheque.films.view.impl.toolbars;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXPanel;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.utils.ui.Borders;
import org.jtheque.primary.view.able.ToolbarView;
import org.jtheque.primary.view.able.ViewMode;
import org.jtheque.primary.view.impl.components.JDropDownButton;
import org.jtheque.utils.ui.GridBagUtils;

import javax.swing.*;
import javax.annotation.PostConstruct;

import java.util.ArrayList;
import java.util.List;
import java.awt.*;

/**
 * Cette classe est la barre d'outils pour le panel des films.
 *
 * @author Baptiste Wicht
 */
public final class JPanelFilmToolBar extends JXPanel implements ToolbarView {
    private static final long serialVersionUID = -688094676844153411L;

    /* Composants graphiques */
    private JDropDownButton buttonAdd;
    private JDropDownButton buttonEdit;
    private JDropDownButton buttonOther;
    private JButton buttonSave;
    private JButton buttonCancel;
    private JButton buttonDelete;

    /* Variables */
    private ViewMode mode = ViewMode.VIEW;

    private final GridBagUtils gbc = new GridBagUtils();
    
    private JThequeAction saveAction;
    private JThequeAction cancelAction;
    private JThequeAction deleteAction;
    private JThequeAction newAction;
    private JThequeAction autoAddAction;
    private JThequeAction manualEditAction;
    private JThequeAction autoEditAction;
    private JThequeAction printAction;
    private JThequeAction sendByMailAction;
    private JThequeAction exportAction;

    /**
     * Cette mthode initialise la toolBar.
     */
    @PostConstruct
    private void build() {
        setBackground(Color.white);
        setBorder(Borders.DIALOG_BORDER);
        
        buttonSave = new JButton(saveAction);
        buttonCancel = new JButton(cancelAction);
        buttonDelete = new JButton(deleteAction);

        List<Action> adds = new ArrayList<Action>(2);
        adds.add(newAction);
        adds.add(autoAddAction);

        buttonAdd = new JDropDownButton(adds);

        List<Action> edits = new ArrayList<Action>(2);
        edits.add(manualEditAction);
        edits.add(autoEditAction);

        buttonEdit = new JDropDownButton(edits);

        List<Action> others = new ArrayList<Action>(2);
        others.add(printAction);
        others.add(sendByMailAction);
        others.add(exportAction);

        buttonOther = new JDropDownButton(others);

        add(Box.createHorizontalGlue(), gbc.gbcSet(0, 0, GridBagConstraints.HORIZONTAL, GridBagConstraints.BASELINE_LEADING, 1.0, 1.0));
        
        if (mode == ViewMode.VIEW) {
            addViewModeButtons();
        } else {
            addOtherModesButton();
        }
    }

    /**
     * Cette mthode permet de modfier le mode.
     *
     * @param mode Le nouveau mode
     */
    void setMode(ViewMode mode) {
        if (this.mode != mode) {
            
            this.mode = mode;

            remove(buttonSave);
            remove(buttonCancel);
            remove(buttonAdd);
            remove(buttonEdit);
            remove(buttonOther);
            remove(buttonDelete);

            switch (mode) {
                case VIEW:
                    addViewModeButtons();
                    
                    break;
                case NEW:
                case EDIT:
                case AUTO:
                    addOtherModesButton();
                        
                    break;
            }
            
            Managers.getManager(IViewManager.class).refresh(this);
        }
    }

    private void addViewModeButtons() {
        add(buttonAdd, gbc.gbcSet(1, 0));
        add(buttonEdit, gbc.gbcSet(2, 0));
        add(buttonDelete, gbc.gbcSet(3, 0));
        add(buttonOther, gbc.gbcSet(4, 0));
    }

    private void addOtherModesButton() {
        add(buttonSave, gbc.gbcSet(1, 0));
        add(buttonCancel, gbc.gbcSet(2, 0));
    }

    @Override
    public void setDisplayMode(ViewMode mode) {
        setMode(mode);
    }

    public void setSaveAction(JThequeAction saveAction) {
        this.saveAction = saveAction;
    }

    public void setCancelAction(JThequeAction cancelAction) {
        this.cancelAction = cancelAction;
    }

    public void setDeleteAction(JThequeAction deleteAction) {
        this.deleteAction = deleteAction;
    }

    public void setNewAction(JThequeAction newAction) {
        this.newAction = newAction;
    }

    public void setAutoAddAction(JThequeAction autoAddAction) {
        this.autoAddAction = autoAddAction;
    }

    public void setManualEditAction(JThequeAction manualEditAction) {
        this.manualEditAction = manualEditAction;
    }

    public void setAutoEditAction(JThequeAction autoEditAction) {
        this.autoEditAction = autoEditAction;
    }

    public void setPrintAction(JThequeAction printAction) {
        this.printAction = printAction;
    }

    public void setSendByMailAction(JThequeAction sendByMailAction) {
        this.sendByMailAction = sendByMailAction;
    }

    public void setExportAction(JThequeAction exportAction) {
        this.exportAction = exportAction;
    }
}